==> xlr-runner-module-24.3.0-rc.1-sources.jar: com/xebialabs/xlrelease/runner/impl/RemoteJobRunnerOps.scala <==
package com.xebialabs.xlrelease.runner.impl

import com.fasterxml.jackson.databind.ObjectMapper
import com.fasterxml.jackson.module.scala.DefaultScalaModule
import com.xebialabs.xlrelease.domain.RemoteExecution
import com.xebialabs.xlrelease.domain.runner.{JobRunner, JobRunnerOps, RemoteJobRunner}
import com.xebialabs.xlrelease.runner.domain._
import com.xebialabs.xlrelease.runner.impl.RunnerProxyActor.NewCommand
import com.xebialabs.xlrelease.service.ConfigurationService
import com.xebialabs.xlrelease.support.pekko.spring.ScalaSpringAwareBean
import grizzled.slf4j.Logging

trait RemoteJobRunnerOps extends JobRunnerOps

object RemoteJobRunnerOps extends RemoteJobRunnerOps with ScalaSpringAwareBean with ContainerTaskToScriptJobDataConversion with Logging {

  private lazy val remoteRunnerProxyActorFactory = springBean[RunnerProxyFactory]
  override lazy val configurationService: ConfigurationService = springBean[ConfigurationService]

  override def objectMapper: ObjectMapper = {
    val mapper = new ObjectMapper()
    mapper.registerModule(DefaultScalaModule)
    mapper
  }

  override def start(runner: JobRunner): Unit = {
    logger.debug(s"Start invoked on $runner")
    val command = EnableRunner(runnerCapacity = runner.capacity, runner.evictionTime, encryptJobData = runner.isEncryptJobData())
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def stop(runner: JobRunner): Unit = {
    logger.debug(s"Stop invoked on $runner")
    val command = DisableRunner()
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def delete(runner: JobRunner): Unit = {
    logger.debug(s"Delete invoked on $runner")
    val command = DeleteRunner()
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def abortJob(runner: JobRunner, jobId: Long, executionId: String): Unit = {
    logger.debug(s"Abort job invoked on $runner")
    val command = Abort(jobId)
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def accepts(runner: JobRunner): Boolean = {
    runner.isInstanceOf[RemoteJobRunner]
  }

  override def execute(runner: JobRunner, remoteExecution: RemoteExecution): String = {
    logger.debug(s"Execute job invoked on $runner")


    val scriptJobData = toScriptJobData(runner.getId, remoteExecution) match {
      case Some(value) => value
      case None =>
        throw ContainerScriptException(s"Unable to create script $remoteExecution job data")
    }

    val command = ExecuteScript(scriptJobData)
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)

    scriptJobData.executionId
  }
}

==> xlr-runner-module-24.3.0-916.1110-sources.jar: com/xebialabs/xlrelease/runner/impl/RemoteJobRunnerOps.scala <==
package com.xebialabs.xlrelease.runner.impl

import com.fasterxml.jackson.databind.ObjectMapper
import com.fasterxml.jackson.module.scala.DefaultScalaModule
import com.xebialabs.xlrelease.domain.RemoteExecution
import com.xebialabs.xlrelease.domain.runner.{JobRunner, JobRunnerOps, RemoteJobRunner}
import com.xebialabs.xlrelease.runner.domain._
import com.xebialabs.xlrelease.runner.impl.RunnerProxyActor.NewCommand
import com.xebialabs.xlrelease.service.ConfigurationService
import com.xebialabs.xlrelease.support.pekko.spring.ScalaSpringAwareBean
import grizzled.slf4j.Logging

trait RemoteJobRunnerOps extends JobRunnerOps

object RemoteJobRunnerOps extends RemoteJobRunnerOps with ScalaSpringAwareBean with ContainerTaskToScriptJobDataConversion with Logging {

  private lazy val remoteRunnerProxyActorFactory = springBean[RunnerProxyFactory]
  override lazy val configurationService: ConfigurationService = springBean[ConfigurationService]

  override def objectMapper: ObjectMapper = {
    val mapper = new ObjectMapper()
    mapper.registerModule(DefaultScalaModule)
    mapper
  }

  override def start(runner: JobRunner): Unit = {
    logger.debug(s"Start invoked on $runner")
    val command = EnableRunner(runnerCapacity = runner.capacity, runner.evictionTime, encryptJobData = runner.isEncryptJobData())
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def stop(runner: JobRunner): Unit = {
    logger.debug(s"Stop invoked on $runner")
    val command = DisableRunner()
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def delete(runner: JobRunner): Unit = {
    logger.debug(s"Delete invoked on $runner")
    val command = DeleteRunner()
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def abortJob(runner: JobRunner, jobId: Long): Unit = {
    logger.debug(s"Abort job invoked on $runner")
    val command = Abort(jobId)
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)
  }

  override def accepts(runner: JobRunner): Boolean = {
    runner.isInstanceOf[RemoteJobRunner]
  }

  override def execute(runner: JobRunner, remoteExecution: RemoteExecution): String = {
    logger.debug(s"Execute job invoked on $runner")


    val scriptJobData = toScriptJobData(runner.getId, remoteExecution) match {
      case Some(value) => value
      case None =>
        throw ContainerScriptException(s"Unable to create script $remoteExecution job data")
    }

    val command = ExecuteScript(scriptJobData)
    remoteRunnerProxyActorFactory.create(()) ! NewCommand(runner.getId, command)

    scriptJobData.executionId
  }
}
